#
# spec file for package k3b
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define with_k3bsetup %(test $(rpm -q --qf='%{VERSION}' libkde4-devel | awk -F. '{print $1 * 10000 + $2 * 100 + $3}') -ge 40385 && echo 1 || echo 0)

%bcond_with ffmpeg
%bcond_with mad
%bcond_with lame

Name:           k3b
BuildRequires:  cups-devel libkcddb4-devel ruby-devel sqlite-devel libtag-devel
BuildRequires:  libkcompactdisc4-devel libkdepimlibs4-devel tse3-devel update-desktop-files
BuildRequires:  gstreamer010-devel libmtp-devel libvisual-devel xine-devel
BuildRequires:  flac-devel libQtWebKit-devel libdvdread-devel libvorbis-devel
BuildRequires:  dbus-1-glib-devel libogg-devel libsamplerate-devel libsndfile-devel
BuildRequires:  libmpcdec-devel libmusicbrainz-devel
# only needed to patch broken images in the upstream tarball:
BuildRequires:  ImageMagick
%if 0%{?suse_version} < 1140
BuildRequires:  libnjb-devel
%endif
%if %{with ffmpeg}
BuildRequires:  libffmpeg_oldabi-devel
%endif
%if %{with mad}
BuildRequires:  libmad-devel
%endif
%if %{with lame}
BuildRequires:  libmp3lame-devel
%endif
Url:            http://k3b.sourceforge.net/
License:        GPLv2+
Group:          Productivity/Multimedia/CD/Record
Summary:        A Universal CD and DVD Burning Application
Requires:       /usr/bin/cdrecord /usr/bin/mkisofs /usr/bin/cdrdao dvd+rw-tools
Version:        2.0.2
Release:        13.10
%define rversion %version
# svn.kde.org/home/kde/trunk/extragear/multimedia/k3b
Source0:        k3b-%{version}.tar.bz2
Patch1:         initial-preference.diff
Patch3:         add_mimetypes_bnc661777.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%kde4_runtime_requires
Requires(post):     shared-mime-info
Requires(postun):   shared-mime-info
Provides:       kde4-k3b = 4.2.1.svn942189
Provides:       kde4-k3b = 4.2.2.svn951754
Obsoletes:      kde4-k3b <= 4.2.2.svn951754
Recommends:     %{name}-lang = %{version}
%if %{with ffmpeg} || %{with mad} || %{with lame}
Recommends:     %{name}-codecs = %{version}-%{release}
%endif
%if 0%{?suse_version} >= 1030
BuildRequires:  fdupes
%endif

%description
K3b is a CD burning application that supports Ogg Vorbis, MP3 audio
files, DVD burning, CDDB, and much more.



Authors:
--------
    Sebastian Trueg <trueg@informatik.uni-freiburg.de>
    Thomas Froescher <tfroescher@gmx.de>

%package devel
Summary:        A Universal CD and DVD Burning Application
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}-%{release}

%description devel
K3b is a CD burning application that supports Ogg Vorbis, MP3 audio
files, DVD burning, CDDB, and much more.



Authors:
--------
    Sebastian Trueg <trueg@informatik.uni-freiburg.de>
    Thomas Froescher <tfroescher@gmx.de>

%if %{with ffmpeg} || %{with mad} || %{with lame}
%package codecs
Summary:        Full Multimedia Codec Support for k3b
Group:          Productivity/Multimedia/CD/Record
Requires:       %{name} = %{version}-%{release}
Enhances:       %{name}
%kde4_runtime_requires

%description codecs
K3b is a CD burning application that supports Ogg Vorbis, MP3 audio
files, DVD burning, CDDB, and much more.

This package contains the support for MP3 and similar codecs.



Authors:
--------
    Sebastian Trueg <trueg@informatik.uni-freiburg.de>
    Thomas Froescher <tfroescher@gmx.de>
%endif

%lang_package
%prep
%setup -q -n k3b-%{version}
%patch1
%patch3

%if %{with mad}
echo "WITH MAD"
%else
echo "WITHOUT MAD"
%endif
%if %{with lame}
echo "WITH LAME"
%else
echo "WITHOUT LAME"
%endif
%if %{with ffmpeg}
echo "WITH FFMPEG"
%else
echo "WITHOUT FFMPEG"
%endif

# patch image with wrong dimensions
pushd src/icons/actions
for f in hi16*.png; do
    geom=$(identify -ping "$f"|cut -f3 -d" ")
    x=${geom%x*}
    y=${geom#*x}
    if [ "$x" != "16" -o "$y" != "16" ]; then
        if [ "$x" -gt "$y" ]; then
            nugeom="${x}x${x}"
            grav=south
        elif [ "$x" -lt "$y" ]; then
            nugeom="${y}x${y}"
            grav=center
        else
            nugeom=""
        fi
        [ -n "$nugeom" ] && mogrify -extent "$nugeom" -background transparent -gravity "$grav" "$f"
        mogrify -scale 16x16 -background transparent "$f"
    fi
done
popd #src/icons/actions

%build
%if 0%{?suse_version} > 1130
CMAKEPARAMS="-DK3B_ENABLE_HAL_SUPPORT=OFF"
%else
CMAKEPARAMS=""
%endif
%if ! %with_k3bsetup
CMAKEPARAMS="-DK3B_BUILD_K3BSETUP=OFF"
%endif

  %cmake_kde4 -d build -- $CMAKEPARAMS
  %make_jobs

%install
  pushd build
  %makeinstall

  %if %{with mad}
  %__install -D -m0755 lib/k3bmaddecoder.so %buildroot/%_libdir/kde4/k3bmaddecoder.so
  %endif

  popd
  %suse_update_desktop_file k3b DiscBurning
  %kde_post_install
  rm -rf $RPM_BUILD_ROOT/usr/share/locale/sr@ijekavian
  rm -rf $RPM_BUILD_ROOT/usr/share/locale/sr@ijekavianlatin
  %find_lang k3b k3b.lang
  %find_lang k3bsetup k3b.lang
  %find_lang libk3b k3b.lang
  %find_lang libk3bdevice k3b.lang
  %find_lang kio_videodvd k3b.lang
  mkdir -p $RPM_BUILD_ROOT/usr/share/icons/hicolor/scalable/apps

%if 0%{?suse_version} >= 1030
%fdupes -s "%{buildroot}%{_datadir}/locale/"
%fdupes -s "%{buildroot}%{_datadir}/kde4/apps/k3b/icons/"
%fdupes -s "%{buildroot}%{_datadir}/kde4/apps/k3b/pics/"
%endif

%post
/sbin/ldconfig
/usr/bin/update-mime-database %{_datadir}/mime &> /dev/null || :

%postun
/sbin/ldconfig
/usr/bin/update-mime-database %{_datadir}/mime &> /dev/null || :

%clean
%{?buildroot:%__rm -rf "%{buildroot}"}

%files lang -f k3b.lang

%files
%defattr(-,root,root)
/usr/bin/k3b
%dir %_libdir/kde4
%_libdir/kde4/k3baudiometainforenamerplugin.so
%_libdir/kde4/k3baudioprojectcddbplugin.so
%_libdir/kde4/k3bexternalencoder.so
%_libdir/kde4/k3bflacdecoder.so
%_libdir/kde4/k3blibsndfiledecoder.so
%_libdir/kde4/k3bmpcdecoder.so
%_libdir/kde4/k3boggvorbisdecoder.so
%_libdir/kde4/k3boggvorbisencoder.so
%_libdir/kde4/k3bsoxencoder.so
%_libdir/kde4/k3bwavedecoder.so
%_libdir/kde4/kcm_k3bexternalencoder.so
%_libdir/kde4/kcm_k3boggvorbisencoder.so
%_libdir/kde4/kcm_k3bsoxencoder.so
/usr/%_lib/kde4/kio_videodvd.so
/usr/%_lib/libk3blib.so.*
/usr/%_lib/libk3bdevice.so.*
/usr/share/applications/kde4/k3b.desktop
/usr/share/kde4/apps/k3b
/usr/share/kde4/apps/konqsidebartng/virtual_folders/services/videodvd.desktop
%dir /usr/share/kde4/services
/usr/share/kde4/services/ServiceMenus/k3b_*
/usr/share/kde4/services/k3baudiometainforenamerplugin.desktop
/usr/share/kde4/services/k3baudioprojectcddbplugin.desktop
/usr/share/kde4/services/k3bexternalencoder.desktop
/usr/share/kde4/services/k3bflacdecoder.desktop
/usr/share/kde4/services/k3blibsndfiledecoder.desktop
/usr/share/kde4/services/k3bmpcdecoder.desktop
/usr/share/kde4/services/k3boggvorbisdecoder.desktop
/usr/share/kde4/services/k3boggvorbisencoder.desktop
/usr/share/kde4/services/k3bsoxencoder.desktop
/usr/share/kde4/services/k3bwavedecoder.desktop
/usr/share/kde4/services/kcm_k3bexternalencoder.desktop
/usr/share/kde4/services/kcm_k3boggvorbisencoder.desktop
/usr/share/kde4/services/kcm_k3bsoxencoder.desktop
/usr/share/kde4/services/videodvd.protocol
/usr/share/kde4/servicetypes/k3bplugin.desktop
%dir /usr/share/kde4/apps/solid
%dir /usr/share/kde4/apps/solid/actions
/usr/share/kde4/apps/solid/actions/k3b_*.desktop
/usr/share/mime/packages/x-k3b.xml
/usr/share/icons/hicolor/*/apps/k3b.*
%if %suse_version < 1120
%dir /usr/share/locale/hne
%dir /usr/share/locale/hne/LC_MESSAGES
%endif
%if %with_k3bsetup
/usr/bin/k3bsetup
%_libdir/kde4/kcm_k3bsetup.so
/usr/%_lib/kde4/libexec/k3bsetuphelper
/usr/share/kde4/services/k3bsetup.desktop
%if %suse_version < 1120
/usr/share/PolicyKit/policy/org.kde.kcontrol.k3bsetup.policy
%else
/usr/share/polkit-1/actions/org.kde.kcontrol.k3bsetup.policy
%endif
/etc/dbus-1/system.d/org.kde.kcontrol.k3bsetup.conf
/usr/share/dbus-1/system-services/org.kde.kcontrol.k3bsetup.service
%endif

%files devel
%defattr(-,root,root)
/usr/include/k3b*
/usr/%_lib/libk3blib.so
/usr/%_lib/libk3bdevice.so

%if %{with ffmpeg} || %{with mad} || %{with lame}
%files codecs
%defattr(-,root,root)
%if %{with ffmpeg}
%_libdir/kde4/k3bffmpegdecoder.so
%_datadir/kde4/services/k3bffmpegdecoder.desktop
%endif #ffmpeg
%if %{with mad}
%_libdir/kde4/k3bmaddecoder.so
%_datadir/kde4/services/k3bmaddecoder.desktop
%endif #mad
%if %{with lame}
%_libdir/kde4/k3blameencoder.so
%_libdir/kde4/kcm_k3blameencoder.so
%_datadir/kde4/services/k3blameencoder.desktop
%_datadir/kde4/services/kcm_k3blameencoder.desktop
%endif #lame
%endif #codecs

%changelog
* Sat May 14 2011 pascal.bleser@opensuse.org
- add strict requires on version *and* release, to avoid unnoticed conflicts
  with other k3b packages
- add "Enhanced: k3b" in k3b-codecs
* Mon Jan 31 2011 detlef@links2linux.de
- update to 2.0.2
* Fri Aug 27 2010 pascal@links2linux.de
- update to 2.0.1
* Sun Jun 27 2010 andrea@opensuse.org
- New upstream version 2.0.0
* Mon May 24 2010 andrea@opensuse.org
- update to 1.92.0 rc3
* Wed Apr 28 2010 Manfred.Tremmel@iiv.de
- fixed build against latest ffmpeg snapshot by redefining
  optflags, included -D__STDC_CONSTANT_MACROS
* Sun Mar 14 2010 pascal@links2linux.de
- update to 1.90.1rc2 (as 1.90.1_rc2, final will be 1.90.1+0)
- translations from SVN
* Tue Feb  2 2010 andrea@opensuse.org
- update to 1.70.0 beta 1
* Wed Dec  2 2009 andrea@opensuse.org
- update to 1.69 alpha 4
* Sat Oct 17 2009 beineri@opensuse.org
- update to 1.68 Alpha 3: many bugfixes
- updated translations from SVN
* Sun Oct  4 2009 beineri@opensuse.org
- updated translations from SVN
* Tue Aug 11 2009 beineri@opensuse.org
- update to r1009369, add documentation & translations (bnc#529600)
* Thu Jul 30 2009 beineri@opensuse.org
- apply trunk diff (r1004480) when building on 11.2
* Thu Jul 23 2009 beineri@opensuse.org
- apply trunk diff (r1001450) when building on 11.2
* Wed May 27 2009 beineri@opensuse.org
- update to 1.66 Alpha 2: many bugfixes
* Sun May  3 2009 cmorve69@yahoo.es
- Add support for Musepack/MPC
- Disable K3BSetup
* Thu Apr 23 2009 beineri@opensuse.org
- rename to k3b, update to 1.65.0 Alpha
* Sat Mar 21 2009 beineri@opensuse.org
- update to 4.2.1.svn942189
* Wed Feb 25 2009 stbinner@suse.de
- update to 4.2.0.svn931376
* Wed Feb 18 2009 stbinner@suse.de
- update to 4.2.0.svn927728
* Fri Jan 23 2009 stbinner@suse.de
- update to 4.1.4.svn915827
* Wed Jan  7 2009 stbinner@suse.de
- update to 4.1.4.svn907132
* Tue Dec 16 2008 stbinner@suse.de
- update to 4.1.3.svn897517
* Sat Nov 22 2008 stbinner@suse.de
- update to 4.1.3.svn887510
* Fri Nov  7 2008 stbinner@suse.de
- update to 4.1.3.svn881374
* Sat Sep 13 2008 stbinner@suse.de
- update to 4.1.1.svn860449
* Fri Aug 22 2008 stbinner@suse.de
- update to 4.1.0.svn851044
* Fri Jul 25 2008 stbinner@suse.de
- update to 4.1.0.svn837567
* Wed Jul 16 2008 stbinner@suse.de
- update to 4.0.98.svn833153
* Fri Jun 27 2008 dmueller@suse.de
- update to 4.0.84.svn825098
* Tue Jun  3 2008 dmueller@suse.de
- update to 4.0.81.svn816194
* Thu May 15 2008 dmueller@suse.de
- update to 4.0.74.svn808129
* Wed May  7 2008 dmueller@suse.de
- update to 4.0.73.svn805196
* Thu Apr 24 2008 dmueller@suse.de
- update to 4.0.71.svn800684
* Fri Apr 18 2008 dmueller@suse.de
- update to 4.0.69.svn798537
* Wed Apr  2 2008 dmueller@suse.de
- update to 4.0.68.svn792936
* Thu Feb 14 2008 dmueller@suse.de
- update to 4.0.62.svn775117
* Wed Nov 28 2007 dmueller@suse.de
- update to 3.96.0.svn742626
* Thu Nov  1 2007 dmueller@suse.de
- update to 3.95.0.svn731749
